"use server";

import { AuthConfig } from "@/auth";
import { requestGetFetch } from "@/utils/fetch";
import { Session, User } from "next-auth";
import { getServerSession } from "next-auth";

export async function userDeleteProfile() {
  try {
    const session: Session = await getServerSession(AuthConfig);
    const token = session?.token;
    const path = "users/remove-user";
    const response = await requestGetFetch({
      path,
      options: {
        method: "Post",
        headers: {
          // credentials: "same-origin",
          // "X-Requested-With": "XMLHttpRequest",
          Authorization: `Bearer ${token}`,
          "Content-Type": "application/json",
          Accept: "application/json",
        },
        cache: 'no-store',
      },
    });
    return response;
  } catch (error) {
    if (error) {
      // switch (error.type) {
      //   case "CredentialsSignin":
      //     return "Invalid credentials.";
      //   default:
      //     return "Something went wrong.";
      // }
    }
    throw error;
  }
}


export async function resetPassword(data: {password: string}) {
  try {
    const session: Session = await getServerSession(AuthConfig);
    const token = session?.token;
    const path = "auth/reset-password";
    const response = await requestGetFetch({
      path,
      options: {
        method: "Post",
        headers: {
          // credentials: "same-origin",
          // "X-Requested-With": "XMLHttpRequest",
          Authorization: `Bearer ${token}`,
          "Content-Type": "application/json",
          Accept: "application/json",
        },
        cache: 'no-store',
        body: JSON.stringify(data || {}),
      },
    });
    return response;
  } catch (error) {
    if (error) {
      // switch (error.type) {
      //   case "CredentialsSignin":
      //     return "Invalid credentials.";
      //   default:
      //     return "Something went wrong.";
      // }
    }
    throw error;
  }
}

export async function userUpdateProfile(data: User) {
  try {
    const session: Session = await getServerSession(AuthConfig);
    const token = session?.token;
    const path = "users/update";
    const response = await requestGetFetch({
      path,
      options: {
        method: "Post",
        headers: {
          // credentials: "same-origin",
          // "X-Requested-With": "XMLHttpRequest",
          Authorization: `Bearer ${token}`,
          "Content-Type": "application/json",
          Accept: "application/json",
        },
        cache: 'no-store',
        body: JSON.stringify(data || {}),
      },
    });
    return response;
  } catch (error) {
    if (error) {
      // switch (error.type) {
      //   case "CredentialsSignin":
      //     return "Invalid credentials.";
      //   default:
      //     return "Something went wrong.";
      // }
    }
    throw error;
  }
}
